#include <hidef.h> /* for EnableInterrupts macro */
#include <stdio.h>
#include <stdlib.h>
#include "derivative.h" /* include peripheral declarations */
#include "demo9S08QG8.h" /*include demo board declarations */

int threshold_failure;
int threshold_test;
int threshold_count;
 
void main(void) 
{
  char i;
  int xx, yy, zz, xxx, yyy, zzz;

  threshold_failure = 0;
  threshold_test = 0;
  threshold_count = 0;

  MCU_init(); // call Device Initialization from MCUInit.c

  //SRTISC_RTIE = 1; // enable RTI

  // set default state of outputs to be safe, even though this is done in MCUInit.c
  OUT1 = LOW;  // LOW = DON'T trigger!
  OUT2 = LOW;
  OUT3 = LOW;
  OUT4 = HIGH;
  
  while(1)
  {  
    xx = yy = zz = 0;

    #define POWSUM 4

    for (i = 0; i < POWSUM; i++) 
    {
        ADCSC1 = X_AXIS; // read X channel
        while(!ADCSC1_COCO);
        xx += ADCR;

        delay(10);

        ADCSC1 = Y_AXIS; // read Y channel
        while(!ADCSC1_COCO);
        yy += ADCR;

        delay(10);
                  
        ADCSC1 = Z_AXIS; // read Z channel
        while(!ADCSC1_COCO);
        zz += ADCR;

        delay(10);
    }

    xxx = xx / POWSUM;
    yyy = yy / POWSUM;
    zzz = zz / POWSUM;

    if ((xxx > THRESH_UPPER_ZEROG) || (xxx < THRESH_LOWER_ZEROG) ||
        (yyy > THRESH_UPPER_ZEROG) || (yyy < THRESH_LOWER_ZEROG) ||
        (zzz > THRESH_UPPER_ZEROG) || (zzz < THRESH_LOWER_ZEROG))
    {
      threshold_failure++;
    }
    threshold_test++;

    
/*    if (xxx > THRESH)
      OUT1 = HIGH;
    else
      OUT1 = LOW;
    
    if (yyy > THRESH)
      OUT2 = HIGH;
    else
      OUT2 = LOW;
    
    if (zzz > THRESH)
      OUT3 = HIGH;
    else
      OUT3 = LOW;*/
  } /* loop forever */
  /* please make sure that you never leave main */
}


// interrupt service routines

void RTI_ISR (void) // 8ms
{
  if ((threshold_failure == 0) && (threshold_test >= 10))
  {
    threshold_count++;
    OUT2 = HIGH;
  }
  else
  {
    threshold_count = 0;
    OUT2 = LOW;
  }
  threshold_failure = 0;
  threshold_test = 0;

  if (threshold_count >= 88)
  {
    OUT1 = HIGH;
  }
           
  SRTISC |= 0x40;  // clear RTIF
}

    

/**************************************************************
*	Function: 	delay
*	Parameters: 16-bit delay value
*	Return:		none
*
*	Simple delay loop.
**************************************************************/
 
void delay(unsigned int count) 
{
	unsigned int i;
	for (i = 0; i < count; i++);
}

// delay the specified number of milliseconds
// not really very accurate because it could get interrupted
void delay_ms(unsigned int ms)  
{
  unsigned int timer;

  while (ms != 0) {
    // this number is dependent on the clock frequency (currently at 16MHz)
    for (timer=0; timer <= 376; timer++);
    ms--;
  }
}
